@@ -1,11 +1,13 @@
 /*--------------------------------*-H-*---------------------------------*
- * File:	feature.h
+ * File:    feature.h
  *----------------------------------------------------------------------*
  *
  * All portions of code are copyright by their respective author/s.
  * Copyright (c) 1997-1998   Oezguer Kesim <kesim@math.fu-berlin.de>
- * Copyright (c) 2005        William P. Y. Hadisoeseno <	 williampoetra@users.sourceforge.net>
- * Copyright (c) 2004-2005   Jingmin Zhou <jimmyzhou@users.sourceforge.net>
+ * Copyright (c) 2005        William P. Y. Hadisoeseno
+ * 					<williampoetra@users.sourceforge.net>
+ * Copyright (c) 2004-2006   Jingmin Zhou <jimmyzhou@users.sourceforge.net>
+ * Copyright (c) 2005-2006   Gautam Iyer <gautam@math.uchicago.edu>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,36 +23,33 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *----------------------------------------------------------------------*/
-/*
-** $Id: feature.h,v 1.25 2005/04/19 21:39:42 cvs Exp $
-*/
 
 #ifndef __FEATURE_H__
 #define __FEATURE_H__
 
 #ifndef X11USRLIBDIR
-# define X11USRLIBDIR		"/usr/X11R6/lib"
+# define X11USRLIBDIR	    "/usr/X11R6/lib"
 #endif
 #ifndef X11LIBDIR
-# define X11LIBDIR		X11USRLIBDIR "/X11"
+# define X11LIBDIR	X11USRLIBDIR "/X11"
 #endif
 #ifndef XAPPLOADDIR
-# define XAPPLOADDIR		X11LIBDIR "/app-defaults" 
-# define XAPPLOADDIRLOCALE	X11LIBDIR "/%-.*s/app-defaults"
+# define XAPPLOADDIR	    X11LIBDIR "/app-defaults" 
+# define XAPPLOADDIRLOCALE  X11LIBDIR "/%-.*s/app-defaults"
 #endif
 
 /* Check ~/.Xdefaults and ~/.Xresources as well */
 #define HAVE_EXTRA_XRESOURCE_FILES
 
 
-/*-----------------------SCREEN OPTIONS AND COLOURS---------------------*/
+/*-----------------------SCREEN OPTIONS AND COLOURS-----------------{{{1*/
 /*
  * Define the name of the environment variable to be used in
  * addition to the "PATH" environment and the `path' resource.
  * Usually it should point to where you keep your background pixmaps and/or
  * your menu files
  */
-#define PATH_ENV	"RXVTPATH"
+#define PATH_ENV    "RXVTPATH"
 
 /*
  * Avoid enabling the colour cursor (-cr, cursorColor, cursorColor2)
@@ -96,39 +95,39 @@
 /*
  * Add support for '-hc colour' for background highlight of selection
  */
-/* #define OPTION_HC */
+#define OPTION_HC
 
 /*
  * Define maximum possible columns and rows
  */
-#define MAX_COLS	1000
-#define MAX_ROWS	1000
+#define MAX_COLS    1000
+#define MAX_ROWS    1000
 
 /*
  * Define default colours for certain items.  If you have a low colour
  * display, then consider using colours which are already pre-allocated:
- *   Black		(#000000)
- *   Red3		(#CD0000)	+ these
- *   Green3		(#00CD00)	+ colours
- *   Yellow3		(#CDCD00)	+ are
- *   Blue3		(#0000CD)	+ not
- *   Magenta3		(#CD00CD)	+ pre-allocated
- *   Cyan3		(#00CDCD)	+ if
- *   AntiqueWhite	(#FAEBD7)	+ NO_BRIGHTCOLOR
- *   Grey25		(#404040)	+ defined
- *   Red		(#FF0000)
- *   Green		(#00FF00)
- *   Yellow		(#FFFF00)
- *   Blue		(#0000FF)
- *   Magenta		(#FF00FF)
- *   Cyan		(#00FFFF)
- *   White		(#FFFFFF)
+ *   Black	(#000000)
+ *   Red3	(#CD0000)   + these
+ *   Green3	(#00CD00)   + colours
+ *   Yellow3	    (#CDCD00)	+ are
+ *   Blue3	(#0000CD)   + not
+ *   Magenta3	    (#CD00CD)	+ pre-allocated
+ *   Cyan3	(#00CDCD)   + if
+ *   AntiqueWhite   (#FAEBD7)	+ NO_BRIGHTCOLOR
+ *   Grey25	(#404040)   + defined
+ *   Red	(#FF0000)
+ *   Green	(#00FF00)
+ *   Yellow	(#FFFF00)
+ *   Blue	(#0000FF)
+ *   Magenta	    (#FF00FF)
+ *   Cyan	(#00FFFF)
+ *   White	(#FFFFFF)
  */
 /* These colours MUST be defined */
-#define COLOR_FOREGROUND	"Black"
-#define COLOR_BACKGROUND	"White"
-#define COLOR_SCROLLBAR		"#B2B2B2"	/* scrollColor match Netscape */
-#define COLOR_SCROLLTROUGH	"#969696"
+#define COLOR_FOREGROUND    "Black"
+#define COLOR_BACKGROUND    "White"
+#define COLOR_SCROLLBAR	    "#B2B2B2"	/* scrollColor match Netscape */
+#define COLOR_SCROLLTROUGH  "#969696"
 /*
  * The cursor colours are special.  Be very careful about setting these:
  * foreground/background colours may be modified by command line or resources
@@ -147,17 +146,16 @@
 /*
  * Printer pipe which will be used for emulation of attached vt100 printer
  */
-#define PRINTPIPE	"lpr"
+#define PRINTPIPE   "lpr"
 
 /*
  * Allow 80/132 mode switching on startup
  */
 /* #define ALLOW_132_MODE */
  
-/*------------------------------RESOURCES-------------------------------*/
+/*------------------------------RESOURCES---------------------------{{{1*/
 /*
  * Define to find installed application defaults for rxvt
- * Only if USE_XGETDEFAULT is not defined.
  */
 /* #define USE_XAPPLOADDIR */
 
@@ -166,75 +164,41 @@
  */
 /* #define OFFIX_DND */
 
-/*---------------------------------KEYS---------------------------------*/
+/*---------------------------------KEYS-----------------------------{{{1*/
 
 /*
  * Define defaults for backspace and delete keys - unless they have been
  * configured out with --disable-backspace-key / --disable-delete-key
  */
-/* #define DEFAULT_BACKSPACE	"DEC"		*/ /* SPECIAL */
-/* #define DEFAULT_BACKSPACE	"\177"		*/
-/* #define DEFAULT_DELETE	"\033[3~"	*/
+/* #define DEFAULT_BACKSPACE	"DEC"	    */ /* SPECIAL */
+/* #define DEFAULT_BACKSPACE	"\177"	    */
+/* #define DEFAULT_DELETE   "\033[3~"	*/
 
 /*
- * Choose one of these values to be the `hotkey' for changing font.
- * This has been superceded and is only for you older users
+ * If defined, then escape sequences for keys with a modifier pressed will be
+ * the same as those sent by Xterm, instead of those sent by rxvt.
  */
-/* #define HOTKEY_CTRL */
-/* #define HOTKEY_META */
+#define XTERM_KEYS
 
 /*
- * To use
- *	Home = "\E[1~", End = "\E[4~"
- * instead of
- *	Home = "\E[7~", End = "\E[8~"	[default]
+ * If defined, then when numlock is on, the DEC terminal sequences sent by all
+ * the keypad keys (including +,-,*, etc) will be the sequences sent with the
+ * shift modifier ignored. Otherwise only the numeric keys and the decimal point
+ * will ignore the shift modifier.
  */
-/* #define LINUX_KEYS */
-/*
-** Notice that we define LINUX_KEYS in the configure script based
-** on the OS type we probe. Uncomment this macro unless you are
-** using non-Linux system, but you want this feature. This feature
-** enable the user to type Home/End key to reach the beginning/end
-** of a command line in shell.
-*/
+#define NUMLOCK_ALWAYS_IGNORES_SHIFT
 
 /*
- * Enable the keysym resource which allows you to define strings associated
- * with various KeySyms (0xFF00 - 0xFFFF).
- * Only works with the default hand-rolled resources.
+ * If defined, macros will be allowed to be "UNSHIFTED" (i.e. your macros don't
+ * necessarily need a modifier key).
  */
-#ifndef NO_RESOURCES
-# define KEYSYM_RESOURCE
-#endif
-
-/*
- * Modifier/s to use to allow up/down arrows and Priot/Next keys
- * to scroll single or page-fulls
- */
-#define SCROLL_ON_SHIFT
-/* #define SCROLL_ON_CTRL */
-/* #define SCROLL_ON_META */
-
-/*
- * Allow scrolling with modifier+Up/Down keys, in addition
- * to modifier+Prior/Next? (modifier is controlled with
- * SCROLL_ON_* defines above.). 
- * Also for modifier+Home/End keys to move to top/bottom
- */
-/* #define SCROLL_ON_UPDOWN_KEYS */
-/* #define SCROLL_ON_HOMEEND_KEYS */
-
-/*
- * Allow unshifted Next/Prior keys to scroll forward/back
- * (in addition to shift+Next/shift+Prior)       --pjh
- */
-/* #define UNSHIFTED_SCROLLKEYS */
+#define UNSHIFTED_MACROS
 
 /* (Hops) Set to choose a number of lines of context between pages
  *      (rather than a proportion (1/5) of savedlines buffer)
  *      when paging the savedlines with SHIFT-{Prior,Next} keys.
  */
-#define PAGING_CONTEXT_LINES 1 /* */
+#define PAGING_CONTEXT_LINES (1)
 
 /*
  * Have either Ctrl+Tab or Mod4+Tab emit \e\t
@@ -250,7 +214,7 @@
 # define GREEK_KEYBOARD_MODESWITCH XK_Mode_switch
 #endif
 
-/*--------------------------------MOUSE---------------------------------*/
+/*--------------------------------MOUSE-----------------------------{{{1*/
 /*
  *  Enable jump scrolling when use mouse wheel
  */
@@ -268,7 +232,7 @@
  * Default separating chars for multiple-click selection
  * Space and tab are separate separating characters and are not settable
  */
-#define CUTCHARS	"\"&'()*,;<=>?@[\\]^`{|}~"
+#define CUTCHARS    "\"&'()*,;<=>?@[\\]^`{|}~"
 
 /*
  * Add run-time support for changing the cutchars for double click selection
@@ -289,7 +253,7 @@
  * Time factor to slow down a `jumpy' mouse.  Motion isn't recognised until
  * this long after the last mouse click [default: 50 milliseconds]
  */
-#define MOUSE_THRESHOLD		50
+#define MOUSE_THRESHOLD	    50
 
 /*
  * If mouse wheel is defined, then scrolling is by 5 lines (or 1 line
@@ -317,7 +281,7 @@
  */
 #define SELECTION_SCROLL_LINE_SPEEDUP 4
 
-/*--------------------------------MISC----------------------------------*/
+/*--------------------------------MISC------------------------------{{{1*/
 /*
  * Disable to reset tty device to pre-incovation state
  */
@@ -340,7 +304,19 @@
 # define ACS_CHARS ".#    o+  ----+---__++--|<> =#. "
 #endif
 
-/*--------------------------------BELL----------------------------------*/
+/*
+ * When executing external commands (e.g. via NewTab macro) use attempt to word
+ * split at quotes internally.
+ */
+/* #define INTERNAL_ARGV_SPLIT */
+
+/*
+ * Maximum number of process (executed via Exec / NewTab macros, or -blc option)
+ * that can be alive at one time.
+ */
+#define MAX_CHILDS  (16)
+
+/*--------------------------------BELL------------------------------{{{1*/
 /*
  * Disable all bell indications
  */
@@ -356,7 +332,12 @@
  */
 #define MAPALERT_OPTION
 
-/*-----------------------------SCROLL BAR-------------------------------*/
+/*------------------------------TAB BAR-----------------------------{{{1*/
+
+/* Default title of new tabs if unspecified */
+#define DEFAULT_TAB_TITLE   "Terminal"
+
+/*-----------------------------SCROLL BAR---------------------------{{{1*/
 /*
  * Choose the rxvt style scrollbar width
  * - should be an even number [default: 10]
@@ -366,8 +347,8 @@
 /*
  * Minimum and maximum widths of the scrollbar (all styles)
  */
-#define SB_WIDTH_MINIMUM 	5
-#define SB_WIDTH_MAXIMUM 	100
+#define SB_WIDTH_MINIMUM    5
+#define SB_WIDTH_MAXIMUM    100
 
 /*
  * When using Rxvt scrollbar, clicking above or below the slider will move
@@ -381,7 +362,7 @@
  */
 /* #define SB_BORDER */
 
-/*------------------------------MENU BAR--------------------------------*/
+/*------------------------------MENU BAR----------------------------{{{1*/
 /*
  * Choose how many of (experimental) menuBars you want to be able to stack at
  * one time.
@@ -389,7 +370,13 @@
  *  A value of 0 disables menuBar all together.
  *  Note that the amount of memory overhead is the same for any value >= 2.
  */
-#define MENUBAR_MAX 8
+/*
+ * 2006-02-04 gi1242: The user interface (using escape sequences) for modifying
+ * menus has been disabled due to a security hole. Thus stacking menubars is
+ * absolutely pointless and a waste of memory. The stacking code has been
+ * removed.
+ */
+/* #define MENUBAR_MAX 8 */
 
 /*
  * Change the default shadow style
@@ -401,13 +388,13 @@
  */
 #define MENU_SHADOW_IN
 
-/*---------------------------MULTILINGUAL-------------------------------*/
+/*---------------------------MULTILINGUAL---------------------------{{{1*/
 /*
  * Allow run-time selection of Meta (Alt) to set the 8th bit on
  */
 #define META8_OPTION
 
-/*---------------------------DISPLAY OPTIONS----------------------------*/
+/*---------------------------DISPLAY OPTIONS------------------------{{{1*/
 /*
  * Force local connection to be socket (or other local) communication
  */
@@ -436,8 +423,7 @@
 #define SMART_WINDOW_TITLE
 
 /*
- * Allow foreground/background colour to be changed with an
- * xterm escape sequence "\E]39;colour^G" -- still experimental
+ * Allow colors to be changed with an xterm escape sequence.
  */
 #define XTERM_COLOR_CHANGE
 
@@ -453,72 +439,110 @@
 /* #define SCROLL_ON_NO_SECONDARY */
 
 /* Width of the term internal border */
-#define DEFAULT_INTERNALBORDERWIDTH	(0)
-#define MAX_INTERNALBORDERWIDTH		(10)
+#define DEFAULT_INTERNALBORDERWIDTH (0)
+#define MAX_INTERNALBORDERWIDTH	    (20)
 
 /* Width of the term external border */
-#define DEFAULT_EXTERNALBORDERWIDTH	(0)
-#define MAX_EXTERNALBORDERWIDTH		(10)
+#define DEFAULT_EXTERNALBORDERWIDTH (0)
+#define MAX_EXTERNALBORDERWIDTH	    (20)
 
 /* Default number of extra dots between lines */
-#define DEFAULT_LINESPACE			(0)
-#define MAX_LINESPACE				(20)
+#define DEFAULT_LINESPACE	    (0)
+#define MAX_LINESPACE		    (20)
 
 /* Default seconds of pointer blank delay */
-#define DEFAULT_BLANKDELAY			(2)
-#define MAX_BLANKDELAY				(20)
+#define DEFAULT_BLANKDELAY	    (2)
+#define MAX_BLANKDELAY		    (20)
 
 /* Default number of lines in the scrollback buffer */
-#define DEFAULT_SAVELINES			(100)
-#define MAX_SAVELINES				(0xffff)
+#define DEFAULT_SAVELINES	    (100)
+#define MAX_SAVELINES		    (0xffff)
 
 /* Default bell throttle interval */
-/*
-#define THROTTLE_BELL_MSEC			(500)
-#define THROTTLE_BELL_COUNT			(3)
-*/
+#define THROTTLE_BELL_MSEC	    (500)
+#define THROTTLE_BELL_COUNT	    (3)
 
 /* Default tabstop size */
-#define TABSTOP_SIZE				(8)
+#define TABSTOP_SIZE		    (8)
 
 /* Maximal length and display length of tab title */
-#define MAX_DISPLAY_TAB_TXT			(27)
-#define MAX_TAB_TXT					(507)
+#define MAX_TAB_TXT		    (507)
+#define MAX_DISPLAY_TAB_TXT	    (40)
+#define MAX_TAB_PIXEL_WIDTH	    (200)
 
-/* Default XFT font pixel size */
-#define MIN_XFT_FONT_SIZE			(8)
-#define DEFAULT_XFT_FONT_SIZE		(12)
+#define DEFAULT_DISPLAY_TAB_TXT	    (27)
+#define DEFAULT_MIN_VISIBLE_TABS    (6)
+
+/* Minimum Xft font size (pixel) */
+#define MIN_XFT_FONT_SIZE	    (8)
+
+/* Default Xft font name and size */
+#define DEFAULT_XFT_FONT_SIZE	    (12)
+#define DEFAULT_XFT_FONT_NAME	    "Monospace"
+
+/* Default Xft propotional font name and size (used for menubar / tabs) */
+#define DEFAULT_XFT_PFONT_SIZE	    (10)
+#define DEFAULT_XFT_PFONT_NAME	    "Sans"
 
 /* Default cursor blinking time (ms) */
-#define MIN_BLINK_TIME				(300)
-#define DEFAULT_BLINK_TIME			(500)
-#define MAX_BLINK_TIME				(5000)
+#define MIN_BLINK_TIME		    (100)
+#define DEFAULT_BLINK_TIME	    (500)
+#define MAX_BLINK_TIME		    (5000)
 
-/* Make text cursor highlighting be the same as color of char
-** that the cursor is currently on */
 /*
+ * Make text cursor highlighting be the same as color of char that the cursor is
+ * currently on.
+ */
 #define CURSOR_COLOR_IS_RENDITION_COLOR
-#define SIMULATE_LINUX_CONSOLE_CURSOR_COLOR
-*/
+/* #define SIMULATE_LINUX_CONSOLE_CURSOR_COLOR */
 
 /* Set tab title on Xterm escape sequence to change window title */
 #define SET_TAB_TITLE_ON_XTERM_SEQUENCE
 /* Set tab title on Xterm escape sequence but not change window title */
 #define SET_TAB_TITLE_NOT_WIN_TITLE
 
-
 /* Enable dead key. To do so, set option "XkbLayout" to "us_intl"
 ** in the keyboard device section. Then disable multichar encoding
 (-km noenc) and use ISO8859-X fonts. */
-/*
 #define USE_DEADKEY
-*/
+
+/* Strip trailing spaces from selection */
+#define DONT_SELECT_TRAILING_SPACES
+
+/*
+ * Default interval (micro secs) to wait before refreshing the background under
+ * pseudo transparency.
+ */
+#define DEFAULT_BG_REFRESH_INTERVAL 100000L
+
+/*
+ * Default interval (micro secs) to wait before fading colors due to a focus
+ * change. This is there mainly to work around bugs of some WM's which send
+ * numerous focus change events over a short event (e.g. when fvwm-2.5.16
+ * changes the miniicon of a window, it sends a FocusOut immediately followed by
+ * a FocusIn).
+ */
+#define DEFAULT_FOCUS_DELAY_INTERVAL 100000L
+
+/*
+ * Default number of pages to skip when jump scrolling.
+ */
+#define DEFAULT_SKIP_PAGES	(25)
+
+/*
+ * If an active tab produces fewer than these many characters, a screen refresh
+ * is requested immediately. Otherwise it is delayed slightly (about 10ms) to
+ * ensure that the active tab is not "flat out" scrolling.
+ */
+#define DEFAULT_REFRESH_LIMIT	(0)
 
 /*
  * Provide termcap/terminfo bw support
  */
 /* #define TERMCAP_HAS_BW */
 
-
 #endif	/* __FEATURE_H__ */
+
+/*}}}1*/
+/* vim: set fdm=marker: */
 /*----------------------- end-of-file (H source) -----------------------*/
