@@ -1,5 +1,5 @@
 /*--------------------------------*-H-*---------------------------------*
- * File:	protos.h
+ * File:    protos.h
  *----------------------------------------------------------------------*
  *
  * All portions of code are copyright by their respective author/s.
@@ -21,30 +21,21 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *----------------------------------------------------------------------*/
-/*
-** $Id: protos.h,v 1.85 2005/03/21 00:42:08 cvs Exp $
-*/
 
 #ifndef __PROTOS_H__
 #define __PROTOS_H__
 
 
 /* Begin prototypes of command.c */
-void             rxvt_init_hotkey_handlers        __PROTO((rxvt_t* r));
-unsigned int     rxvt_cmd_write                   __PROTO((rxvt_t* r, int page, const unsigned char* str, unsigned int count));
-int              rxvt_check_our_parents           __PROTO((rxvt_t *r));
-FILE*            rxvt_popen_printer               __PROTO((rxvt_t *r));
+void		 rxvt_cmd_write                   __PROTO((rxvt_t* r, int page, const unsigned char* str, unsigned int count));
+FILE*            rxvt_popen_printer               __PROTO((rxvt_t *r, const char *pipeName));
 int              rxvt_pclose_printer              __PROTO((FILE *stream));
 void             rxvt_xterm_seq                   __PROTO((rxvt_t* r, int page, int op, const char* str, unsigned char resp __attribute__((unused))));
 void             rxvt_tt_printf                   __PROTO((rxvt_t* r, int page, const char* fmt,...));
 void             rxvt_tt_write                    __PROTO((rxvt_t* r, int page, const unsigned char* d, int len));
 void             rxvt_pointer_unblank             __PROTO((rxvt_t* r, int page));
-#if defined(TRANSPARENT) || defined(BACKGROUND_IMAGE)
-# ifdef TINTING_SUPPORT
-void             rxvt_shade_pixmap                __PROTO((rxvt_t* r, Drawable d, GC gc, int sx, int sy, unsigned int nw, unsigned int nh, int shade, unsigned long pixel));
-# endif
-#endif
 void             rxvt_resize_on_subwin            __PROTO((rxvt_t* r, resize_reason_t reason));
+void           	 rxvt_resize_on_font           	  __PROTO((rxvt_t* r, char* fontname));
 /* End prototypes of command.c */
 
 
@@ -78,29 +69,45 @@ int              greek_xlat                       __PROTO((char* s, int num_char
 #endif
 /* End prototypes of grkelot.c */
 
+/* Begin prototypes of macros.c */
+int		 rxvt_parse_macros		  __PROTO((rxvt_t*, const char *, const char *, Bool noReplace));
+void		 rxvt_cleanup_macros		  __PROTO((rxvt_t*));
+Bool		 rxvt_set_action		  __PROTO((action_t*, char*));
+int		 rxvt_process_macros		  __PROTO((rxvt_t*, KeySym, XKeyEvent*));
+int		 rxvt_dispatch_action		  __PROTO((rxvt_t*, action_t*, XEvent *ev));
+
+void		 rxvt_toggle_verybold		  __PROTO((rxvt_t*));
+void		 rxvt_toggle_subwin		  __PROTO((rxvt_t*, const unsigned char *));
+/* End prototypes of macros.c */
 
 /* Begin prototypes of init.c */
 int              rxvt_init_vars                   __PROTO((rxvt_t* r));
 void             rxvt_init_secondary              __PROTO((rxvt_t* r));
-void             rxvt_init_hotkeys                __PROTO((rxvt_t* r));
-void             rxvt_toggle_hotkeys              __PROTO((rxvt_t* r, int enable));
+void		 rxvt_set_jumpscroll		  __PROTO((rxvt_t* r));
 const char    ** rxvt_init_resources              __PROTO((rxvt_t* r, int argc, const char* const *argv));
-unsigned long    rxvt_fade_color                  __PROTO((rxvt_t* r, unsigned long));
-void             rxvt_switch_fgbg_color           __PROTO((rxvt_t* r, int page));
-int              rxvt_restore_ufbg_color          __PROTO((rxvt_t* r));
-int              rxvt_switch_ufbg_color           __PROTO((rxvt_t* r));
-#ifdef OFF_FOCUS_FADING
-int              rxvt_restore_pix_color           __PROTO((rxvt_t* r));
-int              rxvt_switch_pix_color            __PROTO((rxvt_t* r));
+#ifdef XFT_SUPPORT
+void		 rxvt_fade_color                  __PROTO((rxvt_t* r, const XColor *xcol, unsigned long *pix_return, XftColor *xft_return));
+#else
+void	         rxvt_fade_color                  __PROTO((rxvt_t* r, const XColor *xcol, unsigned long *pix_return, void *xft_return));
 #endif
+int		 rxvt_set_fgbg_colors		  __PROTO((rxvt_t* r, int page));
+int		 rxvt_set_vt_colors		  __PROTO((rxvt_t* r, int page));
+void		 rxvt_copy_color                  __PROTO((rxvt_t*, int, int));
+void		 rxvt_set_color                   __PROTO((rxvt_t*, int, const XColor*));
 void             rxvt_init_env                    __PROTO((rxvt_t *r));
 void             rxvt_init_xlocale                __PROTO((rxvt_t *r));
 void             rxvt_init_command                __PROTO((rxvt_t* r, const char* const *argv));
 CARD32           rxvt_get_desktop                 __PROTO((rxvt_t* r));
 void             rxvt_create_show_windows         __PROTO((rxvt_t* r, int argc, const char* const *argv));
-void             rxvt_create_termwin              __PROTO((rxvt_t* r, int page, const char TAINTED * title));
 void             rxvt_destroy_termwin             __PROTO((rxvt_t* r, int page));
+void             rxvt_create_termwin              __PROTO((rxvt_t* r, int page, int profile,  const char TAINTED * title));
+const char*	 getProfileOption		  __PROTO(( rxvt_t *r, int profile, int resource ));
+Status		 ewmh_message			  __PROTO(( Display *, Window, Window, Atom, long, long, long, long, long));
+int		 rxvt_async_exec		  __PROTO((rxvt_t*, const char *));
 int              rxvt_run_command                 __PROTO((rxvt_t* r, int page, const char** argv));
+void             clean_sigmasks_and_fds           __PROTO((rxvt_t* r, int page));
+termenv_t        rxvt_get_termenv                 __PROTO((const char* str));
+char**		 rxvt_string_to_argv    	  __PROTO((const char*, int*));
 /* End prototypes of init.c */
 
 
@@ -112,14 +119,25 @@ void             rxvt_cleanutent                  __PROTO((rxvt_t* r, int page))
 /* End prototypes of logging.c */
 
 
+/* Begin prototypes of rxvtmem.c */
+#ifdef OUR_MALLOC
+void             rxvt_mem_init                    __PROTO((void));
+void             rxvt_mem_exit                    __PROTO((void));
+#endif /* OUR_MALLOC */
+void*            rxvt_malloc                      __PROTO((size_t size));
+void*            rxvt_calloc                      __PROTO((size_t number, size_t size));
+void*            rxvt_realloc                     __PROTO((void *ptr, size_t size));
+void             rxvt_free                        __PROTO((void *ptr));
+/* End prototypes of rxvtmem.c */
+
+
 /* Begin prototypes of main.c */
 void             rxvt_privileges                  __PROTO((int mode));
 RETSIGTYPE       rxvt_Child_signal                __PROTO((int sig __attribute__((unused))));
 RETSIGTYPE       rxvt_Exit_signal                 __PROTO((int sig));
+void		 rxvt_exit_request                __PROTO((rxvt_t*));
 void             rxvt_clean_exit                  __PROTO((rxvt_t* r));
-void*            rxvt_malloc                      __PROTO((size_t size));
-void*            rxvt_calloc                      __PROTO((size_t number, size_t size));
-void*            rxvt_realloc                     __PROTO((void *ptr, size_t size));
+void		 rxvt_close_all_tabs		  __PROTO((rxvt_t* r));
 void             rxvt_privileged_utmp             __PROTO((rxvt_t* r, int page, char action));
 void             rxvt_privileged_ttydev           __PROTO((rxvt_t* r, int page, char action));
 void             rxvt_tt_winsize                  __PROTO((int fd, unsigned short col, unsigned short row, pid_t pid));
@@ -132,10 +150,10 @@ int              rxvt_change_font_xft             __PROTO((rxvt_t* r, const char
 void             rxvt_set_win_title               __PROTO((rxvt_t* r, Window win, const char* str));
 void             rxvt_set_term_title              __PROTO((rxvt_t* r, const unsigned char* str));
 void             rxvt_set_icon_name               __PROTO((rxvt_t* r, const unsigned char* str));
-void             rxvt_set_window_color            __PROTO((rxvt_t* r, int idx, const char* color));
+void             rxvt_set_window_color            __PROTO((rxvt_t* r, int page, int idx, const char* color));
 void             rxvt_recolour_cursor             __PROTO((rxvt_t *r));
 #ifdef XFT_SUPPORT
-int              rxvt_alloc_xft_color             __PROTO((rxvt_t *r, unsigned long pixel, XftColor* xftcolor));
+int              rxvt_alloc_xft_color             __PROTO((rxvt_t *r, const XColor *xcol, XftColor* xftcolor));
 #endif
 int              rxvt_parse_alloc_color           __PROTO((rxvt_t* r, XColor *screen_in_out, const char* colour));
 int              rxvt_alloc_color                 __PROTO((rxvt_t* r, XColor *screen_in_out, const char* colour));
@@ -143,26 +161,28 @@ void             rxvt_set_widthheight             __PROTO((rxvt_t* r, unsigned i
 void             rxvt_IM_send_spot                __PROTO((rxvt_t *r));
 void             rxvt_IM_set_fontset              __PROTO((rxvt_t* r, int idx));
 void             rxvt_IM_init_callback            __PROTO((Display *unused __attribute__((unused)), XPointer client_data __attribute__((unused)), XPointer call_data __attribute__((unused))));
-void             rxvt_IM_set_status_pos           __PROTO((rxvt_t *r));
+void             rxvt_IM_resize                   __PROTO((rxvt_t *r));
 rxvt_t         * rxvt_get_r                       __PROTO((void));
 /* End prototypes of main.c */
 
 
 /* Begin prototypes of menubar.c */
 #ifdef HAVE_MENUBAR
-void             rxvt_menubar_resize              __PROTO((rxvt_t *r));
-void             rxvt_menubar_create              __PROTO((rxvt_t *r));
-void             rxvt_menubar_clean_exit          __PROTO((rxvt_t *r));
-int              rxvt_menubar_hide                __PROTO((rxvt_t *r));
-int              rxvt_menubar_show                __PROTO((rxvt_t *r));
-void             rxvt_menubar_expose              __PROTO((rxvt_t *r));
-void             rxvt_menubar_dispatcher          __PROTO((rxvt_t* r, char* str));
-void             rxvt_menubar_control             __PROTO((rxvt_t* r, XButtonEvent *ev));
-void             rxvt_menubar_load_file           __PROTO((rxvt_t* r, const char* filename));
-int              rxvt_is_menubar_win              __PROTO((rxvt_t* r, Window w));
-unsigned short   rxvt_menubar_height              __PROTO((rxvt_t *r));
-unsigned short   rxvt_menubar_rheight             __PROTO((rxvt_t *r));
-int              rxvt_menubar_visible             __PROTO((rxvt_t* r));
+void             rxvt_menubar_resize              __PROTO((rxvt_t*));
+void             rxvt_menubar_create              __PROTO((rxvt_t*));
+void             rxvt_menubar_clean_exit          __PROTO((rxvt_t*));
+int              rxvt_menubar_hide                __PROTO((rxvt_t*));
+int              rxvt_menubar_show                __PROTO((rxvt_t*));
+void             rxvt_menubar_expose              __PROTO((rxvt_t*));
+void             rxvt_menubar_dispatcher          __PROTO((rxvt_t*, unsigned char*));
+void             rxvt_menubar_control             __PROTO((rxvt_t*, XButtonEvent*));
+void             rxvt_menubar_load_file           __PROTO((rxvt_t*, const unsigned char*));
+int              rxvt_is_menubar_win              __PROTO((rxvt_t*, Window));
+unsigned short   rxvt_menubar_height              __PROTO((rxvt_t*));
+unsigned short   rxvt_menubar_rheight             __PROTO((rxvt_t*));
+int              rxvt_menubar_visible             __PROTO((rxvt_t*));
+void		 rxvt_menu_show			  __PROTO((rxvt_t*));
+int		 rxvt_menu_select		  __PROTO((rxvt_t*, XButtonEvent*));
 #endif
 /* End prototypes of menubar.c */
 
@@ -174,6 +194,7 @@ int              rxvt_str_match                   __PROTO((const char* s1, const
 const char*      rxvt_str_skip_space              __PROTO((const char* str));
 char*            rxvt_str_trim                    __PROTO((char* str));
 int              rxvt_str_escaped                 __PROTO((char* str));
+int		 rxvt_percent_interpolate         __PROTO((rxvt_t*, int, const char *, int, char *, int));
 char**           rxvt_splitcommastring            __PROTO((const char* cs));
 char*            rxvt_File_find                   __PROTO((const char* file, const char* ext, const char* path));
 void             rxvt_draw_shadow                 __PROTO((Display *Xdisplay, Window win, GC gc, unsigned long topShadow, unsigned long botShadow, int x, int y, int w, int h));
@@ -196,9 +217,15 @@ int              rxvt_control_tty                 __PROTO((int fd_tty, const cha
 
 
 /* Begin prototypes of screen.c */
-void             rxvt_draw_string_x11             __PROTO((rxvt_t* r, Window win, GC gc, int x, int y, char* str, int len, int (*func)()));
+void
+rxvt_draw_string_x11 (rxvt_t* r, Window win, GC gc, Region refreshRegion,
+	int x, int y, char* str, int len, int (*draw_string)());
 #ifdef XFT_SUPPORT
-void             rxvt_draw_string_xft             __PROTO((rxvt_t* r, XftDraw* win, GC gc, XftColor* fore, int x, int y, char* str, int len, void (*func)()));
+void
+rxvt_draw_string_xft (rxvt_t* r, Drawable d, GC gc, Region refreshRegion,
+	rend_t rend, int pfont,
+	XftDraw* win, XftColor* fore, int x, int y, char* str, int len,
+	void (*xftdraw_string)());
 #endif
 void             rxvt_init_screen                 __PROTO((rxvt_t* r));
 void             rxvt_scr_reset                   __PROTO((rxvt_t* r, int page));
@@ -237,8 +264,8 @@ void             rxvt_scr_expose                  __PROTO((rxvt_t* r, int page,
 void             rxvt_scr_touch                   __PROTO((rxvt_t* r, int page, Bool refresh));
 int              rxvt_scr_move_to                 __PROTO((rxvt_t* r, int page, int y, int len));
 int              rxvt_scr_page                    __PROTO((rxvt_t* r, int page, enum page_dirn direction, int nlines));
-void             rxvt_scr_bell                    __PROTO((rxvt_t *r));
-void             rxvt_scr_printscreen             __PROTO((rxvt_t* r, int page, int fullhist));
+void             rxvt_scr_bell                    __PROTO((rxvt_t *r, int page));
+void             rxvt_scr_printscreen             __PROTO((rxvt_t* r, int page, int fullhist, int pretty, int linecont, const char *pipeName));
 void             rxvt_scr_refresh                 __PROTO((rxvt_t* r, int page, unsigned char refresh_type));
 void             rxvt_scr_clear                   __PROTO((rxvt_t* r, int page));
 void             rxvt_scr_dump                    __PROTO((rxvt_t* r, int page, int fd));
@@ -253,7 +280,6 @@ void             rxvt_selection_extend            __PROTO((rxvt_t* r, int page,
 void             rxvt_selection_rotate            __PROTO((rxvt_t* r, int page, int x, int y));
 void             rxvt_process_selectionrequest    __PROTO((rxvt_t* r, int page, const XSelectionRequestEvent *rq));
 void             rxvt_pixel_position              __PROTO((rxvt_t* r, int *x, int *y));
-void             rxvt_setPosition                 __PROTO((rxvt_t* r, XPoint *pos));
 /* End prototypes of screen.c */
 
 
@@ -304,17 +330,18 @@ int              rxvt_scrollbar_show_sgi          __PROTO((rxvt_t* r, int update
 
 /* Begin prototypes of scrollbar.c */
 #ifdef HAVE_SCROLLBARS
-int              rxvt_scrollbar_visible           __PROTO((rxvt_t *r));
-void             rxvt_scrollbar_init              __PROTO((rxvt_t *r));
-void             rxvt_scrollbar_create            __PROTO((rxvt_t *r));
-void             rxvt_scrollbar_clean_exit        __PROTO((rxvt_t *r));
-void             rxvt_scrollbar_resize            __PROTO((rxvt_t *r));
-int              rxvt_scrollbar_hide              __PROTO((rxvt_t *r));
-int              rxvt_scrollbar_show              __PROTO((rxvt_t *r));
+int              rxvt_scrollbar_visible           __PROTO((rxvt_t* r));
+void             rxvt_scrollbar_init              __PROTO((rxvt_t* r));
+void             rxvt_scrollbar_create            __PROTO((rxvt_t* r));
+void             rxvt_scrollbar_clean_exit        __PROTO((rxvt_t* r));
+void             rxvt_scrollbar_resize            __PROTO((rxvt_t* r));
+int              rxvt_scrollbar_hide              __PROTO((rxvt_t* r));
+int              rxvt_scrollbar_show              __PROTO((rxvt_t* r));
 int              rxvt_scrollbar_update            __PROTO((rxvt_t* r, int update));
-unsigned short   rxvt_scrollbar_width             __PROTO((rxvt_t *r));
-unsigned short   rxvt_scrollbar_rwidth            __PROTO((rxvt_t *r));
+unsigned short   rxvt_scrollbar_width             __PROTO((rxvt_t* r));
+unsigned short   rxvt_scrollbar_rwidth            __PROTO((rxvt_t* r));
 int              rxvt_is_scrollbar_win            __PROTO((rxvt_t* r, Window w));
+unsigned long	 rxvt_scrollbar_bg		  __PROTO((rxvt_t* r));
 #endif
 /* End prototypes of scrollbar.c */
 
@@ -345,8 +372,29 @@ void*            ma_memcpy                        __PROTO((void *s1, const void
 void*            ma_memmove                       __PROTO((void *d, const void *s, size_t len));
 void             ma_bzero                         __PROTO((void *b, size_t len));
 void*            ma_memset                        __PROTO((void *p, int c1, size_t len));
+char*		 ma_strcasestr			  __PROTO((const char* phaystack, const char *pneedle));
+
 /* End prototypes of strings.c */
 
+/* Begin prototypes of transparent.c */
+int		rxvt_set_opacity	     	 __PROTO((rxvt_t*));
+void		rxvt_process_reparentnotify   	 __PROTO((rxvt_t*, XEvent*));
+#ifdef TRANSPARENT
+void		rxvt_toggle_transparency	 __PROTO((rxvt_t*));
+void		refreshRootBGVars		 __PROTO((rxvt_t*));
+int             rxvt_check_our_parents           __PROTO((rxvt_t*));
+#endif
+#if defined(TRANSPARENT) || defined(BACKGROUND_IMAGE)
+void		rxvt_refresh_bg_image		 __PROTO((rxvt_t*, int, Bool));
+#endif
+#ifdef TINTING_SUPPORT
+# if defined(HAVE_LIBXRENDER)
+void		xrenderShadeParentPixmap     	 __PROTO((rxvt_t*, Pixmap, int, int, unsigned, unsigned, Bool));
+# else
+void            rxvt_shade_pixmap                __PROTO((rxvt_t*, Drawable, int, int, unsigned, unsigned));
+# endif
+#endif
+/* End prototypes of transparent.c */
 
 /* Begin prototypes of xdefaults.c */
 void             rxvt_usage                       __PROTO((int type));
@@ -381,44 +429,31 @@ long             PngReadFileToPixmap             __PROTO((Display* display, Wind
 
 
 /* Begin prototypes of tabbar.c */
-void             rxvt_append_page               __PROTO((rxvt_t* r, const char TAINTED * title));
-void             rxvt_kill_page                 __PROTO((rxvt_t* r, int page));
-void             rxvt_remove_page               __PROTO((rxvt_t* r, int page));
-void             rxvt_activate_page             __PROTO((rxvt_t* r, int page));
-void             rxvt_tabbar_set_visible_tabs   __PROTO((rxvt_t* r));
-void             rxvt_tabbar_set_title          __PROTO((rxvt_t* r, int page, const unsigned char TAINTED * str));
-void             rxvt_tabbar_resize             __PROTO((rxvt_t* r));
-void             rxvt_tabbar_dispatcher         __PROTO((rxvt_t* r, XButtonEvent* ev));
-int              rxvt_tabbar_visible            __PROTO((rxvt_t* r));
-void             rxvt_tabbar_expose             __PROTO((rxvt_t* r));
-int              rxvt_tabbar_hide               __PROTO((rxvt_t* r));
-int              rxvt_tabbar_show               __PROTO((rxvt_t* r));
-void             rxvt_tabbar_create             __PROTO((rxvt_t* r));
-void             rxvt_tabbar_clean_exit         __PROTO((rxvt_t* r));
-unsigned short   rxvt_tabbar_height             __PROTO((rxvt_t* r));
-unsigned short   rxvt_tabbar_rheight            __PROTO((rxvt_t* r));
-unsigned int     rxvt_tab_width                 __PROTO((rxvt_t* r, const char* str));
-int              rxvt_is_tabbar_win             __PROTO((rxvt_t* r, Window w));
-void             rxvt_tabbar_draw_buttons       __PROTO((rxvt_t* r));
-void             rxvt_tabbar_change_color       __PROTO((rxvt_t* r, int item, const char* color));
-void             rxvt_tabbar_highlight_tab      __PROTO((rxvt_t* r, int page));
-void             rxvt_tabbar_move_tab           __PROTO((rxvt_t* r, int to_right));
+void             rxvt_append_page               __PROTO((rxvt_t*, int profile, const char TAINTED *title, const char *command));
+void             rxvt_kill_page                 __PROTO((rxvt_t*, short));
+void             rxvt_remove_page               __PROTO((rxvt_t*, short));
+void             rxvt_activate_page             __PROTO((rxvt_t*, short));
+void		 rxvt_tabbar_set_visible_tabs   __PROTO((rxvt_t*, Bool));
+void             rxvt_tabbar_set_title          __PROTO((rxvt_t*, short, const unsigned char TAINTED *));
+void             rxvt_tabbar_resize             __PROTO((rxvt_t*));
+void             rxvt_tabbar_dispatcher         __PROTO((rxvt_t*, XButtonEvent*));
+void		 rxvt_tabbar_button_release     __PROTO((rxvt_t*, XButtonEvent*));
+int              rxvt_tabbar_visible            __PROTO((rxvt_t*));
+void             rxvt_tabbar_expose             __PROTO((rxvt_t*, XEvent*));
+int              rxvt_tabbar_hide               __PROTO((rxvt_t*));
+int              rxvt_tabbar_show               __PROTO((rxvt_t*));
+void             rxvt_tabbar_create             __PROTO((rxvt_t*));
+void             rxvt_tabbar_clean_exit         __PROTO((rxvt_t*));
+unsigned short   rxvt_tabbar_height             __PROTO((rxvt_t*));
+unsigned short   rxvt_tabbar_rheight            __PROTO((rxvt_t*));
+unsigned int     rxvt_tab_width                 __PROTO((rxvt_t*, const char*));
+int              rxvt_is_tabbar_win             __PROTO((rxvt_t*, Window));
+void             rxvt_tabbar_draw_buttons       __PROTO((rxvt_t*));
+void             rxvt_tabbar_change_color       __PROTO((rxvt_t*, int, const char*));
+void             rxvt_tabbar_highlight_tab      __PROTO((rxvt_t*, short, Bool));
+void             rxvt_tabbar_move_tab           __PROTO((rxvt_t*, short));
 /* Begin prototypes of tabbar.c */
 
-
-/* Begin prototypes of thai.c */
-#ifdef THAI
-int              ThaiIsMiddleLineCh             __PROTO((char ch));
-int              ThaiPixel2Col                  __PROTO((rxvt_t* r, int page, int x, int y));
-int              ThaiCol2Pixel                  __PROTO((rxvt_t* r, int col, char* start));
-int              ThaiUpdateMap2                 __PROTO((rxvt_t* r, text_t* stp, text_t* dtp, rend_t* srp, rend_t* drp, char* map, int len));
-int              ThaiUpdateMap                  __PROTO((text_t* stp, text_t* dtp, rend_t* srp, rend_t* drp, char* map, int len));
-int              Thai_CursorArea                __PROTO((char* stp, char* map, int len, int col));
-int              Thai_ColMaxPaint               __PROTO((text_t* str, int len));
-#endif	/* THAI */
-/* End prototypes of thai.c */
-
-
 /* Begin prototypes of session.c */
 #ifdef HAVE_X11_SM_SMLIB_H
 void            rxvt_process_ice_msgs          __PROTO((rxvt_t* r));
